@@ -593,11 +593,11 @@
 
 .get_model_data <- function(model) {
   # get model frame
-  model_frame <- insight::get_data(model, source = "frame")
+  model_frame <- insight::get_data(model, source = "frame", verbose = FALSE)
 
   # sanity check - could data be extracted from model frame?
   if (is.null(model_frame)) {
-    model_frame <- .safe(insight::get_data(model, source = "environment"))
+    model_frame <- .safe(insight::get_data(model, source = "environment", verbose = FALSE))
   }
 
   # tibbles are not supported
